#include "jcabc2ps.h"

int mempad = 0;		// Pad chars to add to mallocs

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* Allocate, reallocate or free a chunk of memory.  This  is  a  debug  wrapper
* around  the  library  malloc() functions.   We now support three different ways
* of allocating memory, depending on the variable.
*/
void* memBlock(
	void*  ptr,		// Block to reallocate, if any
	size_t oldsize,	// Size of old block
	size_t newsize,	// Min size of new block
	char*  dsc)		// Description, for messages
{	void*  val=0;
	int    i;
	char*  F="memBlock";
	V3 "%s: ptr=%lX oldsize=%zu newsize=%zu mempad=%d \"%s\"\n"
		,F,(ulong)ptr,oldsize,newsize,mempad,dsc V;
	newsize += mempad;
	unless (ptr || newsize>0) return val;
	unless (dsc) dsc = "???";
	unless (ptr) {	// No old block; allocate a new one.
		if (newsize == 0) {
			V6 "%s: No old block; no new block requested.\n",F V;
			return val;
		}
		V6 "%s: malloc(%zu) for \"%s\"\n",F,newsize,dsc V;
		unless (val = (void*)malloc(newsize)) {
			V1 "%s: ### Can't get %zu bytes [OUT OF MEMORY]\n",F,newsize V;
			return 0;
		}
		V6 "%s: Got %08lX for \"%s\"\n",F,(ulong)val,dsc V;
		bzero(val,newsize);
		return val;
	}
//	if (chkchunks) chkblock(ptr,oldsize,"old memchunk");	// Sanity test
	unless (newsize > 0) {	// Just free the old block
		free(ptr);
		return val;
	}
	V5 "%s: Enlarge: %08lX (%s) from %zu to %zu bytes.\n",F,(ulong)ptr,dsc,oldsize,newsize V;
	unless (val = (void*)malloc(newsize)) {
		V1 "%s: ### Can't enlarge %08lX (%s) from %ld to %ld bytes [OUT OF MEMORY]\n",F,(ulong)ptr,dsc,(ulong)oldsize,(ulong)newsize V;
		return 0;
	}
	bcopy(ptr,val,oldsize);
//	if (chkchunks) chkblock(val,newsize,"new memchunk");
	bzero(ptr+oldsize,oldsize-newsize);
	V5 "%s: Enlarged %08lX (%s) from %ld to %ld bytes.\n",F,(ulong)ptr,dsc,(ulong)oldsize,(ulong)newsize V;
	free(ptr);
	V5 "%s: Return %08lX newsize=%ld for \"%s\"\n",F,(ulong)val,(ulong)newsize,dsc V;
	return val;
}

